@@ -1,7 +1,7 @@
 import requests
 import json
 
-class client:
+class Client:
 
     def __init__(self, client_id):
         self.client_id = client_id
